"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.clear = void 0;

/**
 * @memberof module:browser
 * @name localStorage
 * @example
 * import localStorage from 'sd-tools/browser/localStorage'
 * @description
 */
var storage = {};

if (typeof window !== 'undefined') {
  storage = window.localStorage;
}

var setItem = function setItem(key, value) {
  try {
    storage.setItem(key, value);
  } catch (e) {
    // when localStorage is full then clear it
    if (e.name === 'QUOTA_EXCEEDED_ERR' || e.name === 'NS_ERROR_DOM_QUOTA_REACHED') {
      storage.clear(true);

      try {
        storage.setItem(key, value);
      } catch (err) {}
    }
  }
};

var getItem = function getItem(key) {
  try {
    return storage.getItem(key);
  } catch (e) {}
};

var removeItem = function removeItem(keys) {
  try {
    if (!Array.isArray(keys)) {
      return storage.removeItem(keys);
    }

    keys.forEach(function (key) {
      storage.removeItem(key);
    });
  } catch (e) {}
};

var clear = function clear(force) {
  if (!force) {
    return console.warn('I sure hope you know what you are doing.');
  }

  try {
    return storage.clear();
  } catch (e) {}
};

exports.clear = clear;
var _default = {
  setItem: setItem,
  set: setItem,
  getItem: getItem,
  get: getItem,
  removeItem: removeItem,
  remove: removeItem,
  clear: clear
};
exports.default = _default;