"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.isBrowser = exports.isMiniProgram = exports.isQQ = exports.isWeibo = exports.isWechat = exports.getOs = exports.getPlatform = exports.osEnum = exports.platformEnum = void 0;
var platformEnum = {
  WECHAT: 1,
  BROWSER: 2,
  MIMIPROGRAM: 5,
  WEIBO: 10,
  QQ: 11
};
exports.platformEnum = platformEnum;
var osEnum = {
  ANDROID: 1,
  IOS: 2,
  OTHER: 10
};
exports.osEnum = osEnum;

var getPlatform = function getPlatform() {
  var ua = navigator.userAgent; // 微信平台

  if (/micromessenger/i.test(ua) && !(/wxwork/i.test(ua) && window.__wxjs_environment !== 'miniprogram')) {
    return platformEnum.WECHAT;
  } else // 微博
    if (/weibo/i.test(ua)) {
      return platformEnum.WEIBO;
    } else // QQ
      if (/qq/i.test(ua)) {
        return platformEnum.QQ;
      } else if (window.__wxjs_environment === 'miniprogram') {
        return platformEnum.MIMIPROGRAM;
      }

  return platformEnum.BROWSER;
};

exports.getPlatform = getPlatform;

var getOs = function getOs() {
  var ua = navigator.userAgent; // Android

  if (/Android/i.test(ua)) {
    return osEnum.ANDROID;
  } else // IOS
    if (/iPhone\sOS/i.test(ua)) {
      return osEnum.IOS;
    }

  return osEnum.OTHER;
};

exports.getOs = getOs;

var isWechat = function isWechat() {
  return getPlatform() === platformEnum.WECHAT;
};

exports.isWechat = isWechat;

var isWeibo = function isWeibo() {
  return getPlatform() === platformEnum.WEIBO;
};

exports.isWeibo = isWeibo;

var isQQ = function isQQ() {
  return getPlatform() === platformEnum.QQ;
};

exports.isQQ = isQQ;

var isMiniProgram = function isMiniProgram() {
  return getPlatform() === platformEnum.MIMIPROGRAM;
};

exports.isMiniProgram = isMiniProgram;

var isBrowser = function isBrowser() {
  return getPlatform() === platformEnum.BROWSER;
};

exports.isBrowser = isBrowser;

var isAndroid = function isAndroid() {
  return getOs() === osEnum.ANDROID;
};

var isIOS = function isIOS() {
  return getOs() === osEnum.IOS;
};

var _default = {
  // 显示平台
  platformEnum: platformEnum,
  osEnum: osEnum,
  getPlatform: getPlatform,
  getOs: getOs,
  isWechat: isWechat,
  isWeibo: isWeibo,
  isQQ: isQQ,
  isBrowser: isBrowser,
  isAndroid: isAndroid,
  isIOS: isIOS
};
exports.default = _default;