"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var ONE_DAY_MS = 1000 * 60 * 60 * 24;
var storage = window.localStorage;

var setItem = function setItem(key, data) {
  var _ref = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {},
      expire = _ref.expire;

  if (expire && expire > 0) {
    data = {
      _t: ONE_DAY_MS * expire + Date.now(),
      data: data
    };
  }

  try {
    storage.setItem(key, JSON.stringify(data));
  } catch (e) {
    // when localStorage is full then clear it
    if (e.name === 'QUOTA_EXCEEDED_ERR' || e.name === 'NS_ERROR_DOM_QUOTA_REACHED') {
      storage.clear(true);

      try {
        storage.setItem(key, data);
      } catch (err) {}
    }
  }
};

var getItem = function getItem(key) {
  try {
    var data = JSON.parse(storage.getItem(key));
    if (!data._t) return data;

    if (data._t > Date.now()) {
      return data.data;
    }

    storage.removeItem(key);
  } catch (e) {}
};

var removeItem = function removeItem(keys) {
  try {
    if (!Array.isArray(keys)) {
      return storage.removeItem(keys);
    }

    keys.forEach(function (key) {
      storage.removeItem(key);
    });
  } catch (e) {}
};

var _default = {
  setItem: setItem,
  set: setItem,
  getItem: getItem,
  get: getItem,
  removeItem: removeItem,
  remove: removeItem
};
exports.default = _default;