"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.travel = travel;

/**
 * 时间穿越
 * @memberof module:date
 * @param {number} num 穿越的范围，负数表示向后穿越，正数向前穿越
 * @param {date} date 基础时间点
 * @param {enum} type 穿越的类型，day、month、year
 * @return {date} 穿越后的时间
 * @example
 * const travel = require('sd-tools/date/travel')
 * const formatDate = require('sd-tools/date/formatDate')
 * // 穿越到10天前
 * formatDate(travel(-10), 'YYYY-MM-DD')
 * // 穿越到15天后
 * formatDate(travel(15), 'YYYY-MM-DD')
 * // 穿越到1个月前
 * formatDate(travel(-1, new Date(), 'month'), 'YYYY-MM-DD')
 * // 穿越到1年前的今天
 * formatDate(travel(-1, new Date(), 'year'), 'YYYY-MM-DD')
 */
function travel(num) {
  var date = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : new Date();
  var type = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 'day';
  var year = date.getFullYear();
  var month = date.getMonth();
  var day = date.getDate();
  return new Date(type === 'year' ? year + num : year, type === 'month' ? month + num : month, type === 'day' ? day + num : day);
}